\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{iscamiabstract}[2025/01/01 ISCAMI 2025 Abstract Submission Class]

% Default options
%\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}

% Paper size and font size
\LoadClass[a5paper,10pt,twoside]{article}

% Setting margins for A5 paper
\RequirePackage{geometry}
\usepackage{geometry}
\geometry{
    b5paper,
    inner=25mm,
    outer=25mm,
    top=25mm,
    bottom=25mm,
    bindingoffset=0mm,
}

% Additional packages
\RequirePackage{graphicx}  % for including images
\RequirePackage{amsmath}   % for advanced math typesetting
\RequirePackage{etoolbox}  % for command customization

% Custom title, author, and institution commands
\newcommand{\titleabstract}[1]{\def\@title{#1}}
\newcommand{\authors}[1]{\def\@authors{\formatauthors{#1}}}
\newcommand{\institutions}[1]{\def\@institutions{\formatinstitutions{#1}}}

% Helper command to format authors with correct commas and "and"
\newcommand{\formatauthors}[1]{%
    \def\temp{}%
    \renewcommand{\and}{, }%
    \renewcommand{\lastand}{\temp}%
    \renewcommand{\do}[1]{%
        \ifx\temp\empty
            \def\temp{##1}%
        \else
            \ifx\do\lastand
                \temp \unskip, and ##1
            \else
                \temp \unskip, ##1
            \fi
        \fi
    }%
    \docsvlist{#1}%
}

% Helper command to format institutions
\newcommand{\formatinstitutions}[1]{%
    \renewcommand{\do}[1]{\vspace{2ex}\\\textit{##1}\vspace{1ex}}%
    \docsvlist{#1}%
}

% Custom command to process the list of authors and institutions
\renewcommand{\docsvlist}[1]{\forcsvlist{\do}{#1}}

% Author command with institution linking
\newcommand{\addauthor}[2]{%
    \noindent\textbf{#1}\textsuperscript{#2} \\[1ex]
}

% Custom title and authors/institutions display
\newcommand{\displaytitleauthorsinstitutions}{
    \begin{center}
        {\LARGE \textbf{\@title}}\\[2ex]
        {\large \@authors}\\[2ex]
        \@date
    \end{center}
    \begin{flushleft}
        \@institutions
    \end{flushleft}
}

% Custom maketitle command
\renewcommand{\maketitle}{
    \begin{center}%
        {\large \textbf{\@title}}\\[2ex]%
        {\@author} \\[3ex]%
        %\@date%
    \end{center}%
    %\formatinstitutions
}

\newcommand\blfootnote[1]{%
  \begingroup
  \renewcommand\thefootnote{}\footnote{#1}%
  \addtocounter{footnote}{-1}%
  \endgroup
}

\newcounter{instfn}
\newcommand{\addInstitution}[2]{\stepcounter{instfn}\blfootnote{$^{\theinstfn}$ #1 \newline \email{#2}}}
\newcommand{\addSingleInstitution}[2]{\blfootnote{#1 \newline \email{#2}}}

% Email command
\newcommand{\email}[1]{\texttt{#1}}

% Custom section formatting (optional)
\RequirePackage{titlesec}
\titleformat{\section}{\large\bfseries}{\thesection}{1em}{}
\titleformat{\subsection}{\normalsize\bfseries}{\thesubsection}{1em}{}

% End of class file
\endinput